@@ -281,18 +281,12 @@ class Response:
 
             content = self._readto(b"\r\n")
             if title and content:
-                title = str(title, "utf-8")
+                # enforce that all headers are lowercase
+                title = str(title, "utf-8").lower()
                 content = str(content, "utf-8")
-                # Check len first so we can skip the .lower allocation most of the time.
-                if (
-                    len(title) == len("content-length")
-                    and title.lower() == "content-length"
-                ):
+                if title == "content-length":
                     self._remaining = int(content)
-                if (
-                    len(title) == len("transfer-encoding")
-                    and title.lower() == "transfer-encoding"
-                ):
+                if title == "transfer-encoding":
                     self._chunked = content.strip().lower() == "chunked"
                 self._headers[title] = content
 
@@ -430,9 +424,7 @@ class Session:
             retry_count += 1
 
             try:
-                sock = self._socket_pool.socket(
-                    addr_info[0], addr_info[1], addr_info[2]
-                )
+                sock = self._socket_pool.socket(addr_info[0], addr_info[1])
             except OSError:
                 continue
             except RuntimeError:
@@ -587,7 +579,27 @@ class Session:
 
         resp = Response(socket, self)  # our response
         if "location" in resp.headers and 300 <= resp.status_code <= 399:
-            raise NotImplementedError("Redirects not yet supported")
+            # a naive handler for redirects
+            redirect = resp.headers["location"]
+
+            if redirect.startswith("http"):
+                # absolute URL
+                url = redirect
+            elif redirect[0] == "/":
+                # relative URL, absolute path
+                url = "/".join([proto, dummy, host, redirect[1:]])
+            else:
+                # relative URL, relative path
+                path = path.rsplit("/", 1)[0]
+
+                while redirect.startswith("../"):
+                    path = path.rsplit("/", 1)[0]
+                    redirect = redirect.split("../", 1)[1]
+
+                url = "/".join([proto, dummy, host, path, redirect])
+
+            self._last_response = resp
+            resp = self.request(method, url, data, json, headers, stream, timeout)
 
         self._last_response = resp
         return resp
@@ -652,9 +664,12 @@ class _FakeSSLContext:
 def set_socket(sock, iface=None):
     """Legacy API for setting the socket and network interface. Use a `Session` instead."""
     global _default_session  # pylint: disable=global-statement,invalid-name
-    _default_session = Session(sock, _FakeSSLContext(iface))
-    if iface:
-        sock.set_interface(iface)
+    if not iface:
+        # pylint: disable=protected-access
+        _default_session = Session(sock, _FakeSSLContext(sock._the_interface))
+    else:
+        _default_session = Session(sock, _FakeSSLContext(iface))
+    sock.set_interface(iface)
 
 
 def request(method, url, data=None, json=None, headers=None, stream=False, timeout=1):
